/**************************************************************/
/** Gestisce statistiche TRIMES SU Facebook PAGE LEVEL DATA  **/
/** Author: @mauroferri Data: 10/4/2018 TAB.1-18 GRAFICI     **/
/**************************************************************/

TITLE1 'COMUNE DI RIMINI - UFFICIO COMUNICAZIONE';

%let trimestre=Primo Trimestre 2018; /* Inserire denominazione intervallo */
%let suffissofile=page1T18;
%let path=/folders/myfolders/sasuser.v94/facebook/;
%let eticpaesi=etichette-paesi.txt;             /* Tabelle 18 - 22 - 28 */
%let eticcitta=etichette-citta.txt;             /* Tabelle 31 */
%let varcitta=variabilicitta.txt;               /* Tabelle 31 */
%let eticdomini=etichette-domini.txt;           /* Tabelle 38 */
%let vardomini=variabilidomini.txt;
TITLE2 "Facebook Insights PAGE Level - &trimestre";
FOOTNOTE2 "Elaborazione della Redazione web &SYSDATE- Thanks to Sas University Edition 2.7 9.4 M5";
OPTIONS linesize=116 PAGESIZE=62 NONUMBER NODATE CENTER COMPRESS=yes;
LIBNAME facebook "/folders/myfolders/sasuser.v94/facebook";
%let page=/folders/myfolders/sasuser.v94/facebook/Facebook Insights Data Export - Comune di Rimini - 2018-04-04.xlsx;
filename percorso "&path";
%let datada=01JAN2018; /* Intervallo data da: configurare */
%let dataa=31MAR2018;  /* Intervallo data a: configurare */
RUN;

/******************/
/* 00 KEY METRICS */
/******************/
TITLE3 "#0 KEY METRICS";
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.key_metrics_page_00
		    DBMS=XLSX
		    REPLACE;
		    DATAROW=3;
SHEET="Key Metrics";
RUN;

DATA TEMP(RENAME=(Nuovi__Mi_piace__al_giorno=mi_piace) rename=(Non_mi_piace_pi___al_giorno=nonmipiace) 
rename=(Utenti_coinvolti_sulla_Pagina_al=utenticoinvolti) rename=(Copertura_totale_al_giorno=copertura)
rename=(Consumatori_totali_al_giorno=consumatori) rename=(Utilizzi_della_Pagina_al_giorno=utilizzi)
rename=(Registrazioni_totali_al_giorno=registrazioni) rename=(Numero_di_clic_sul_sito_Web_in_t=clicksitoweb)
rename=(Commenti_negativi_al_giorno=commentinegativi) rename=(Impression_totali_al_giorno=impressiontot)
);
mese=month(Data);
SET facebook.key_metrics_page_00;
WHERE Data not is missing;
RUN;

proc sort data=TEMP out=temp1; /* Passo data per i grafici */
by mese;
where mese <> 12; /* Da correggere */
Run;

title3 "Metriche di pagina per Data - &trimestre";
title4 "Andamento Trimestrale Mi piace";
proc sgplot data=temp1 noborder;
series x=data y=_Mi_piace__in_totale  / smoothconnect lineattrs=(color=green thickness=2);
xaxis display=(nolabel) grid min="&datada"d max="&dataa"d;
yaxis display=(noline noticks) grid;
run;

title3 "Metriche di pagina per Data - &trimestre";
title4 "Mi piace e Non mi piace al giorno";
proc sgplot data=temp1 noborder;
series x=data y=mi_piace / lineattrs=(color=green thickness=2);
series x=data y=nonmipiace / lineattrs=(color=red thickness=1)  ;
xaxis display=(nolabel) grid min="&datada"d max="&dataa"d;
yaxis display=(noline noticks) grid;
run;

title3 "Metriche di pagina per Data - &trimestre";
title4 "Copertura totale e utilizzi della pagina al giorno";
proc sgplot data=temp1 noborder;
series x=data y=copertura / lineattrs=(color=blue thickness=2);
series x=data y=Utilizzi / lineattrs=(color=cyan thickness=2);
xaxis display=(nolabel) grid min="&datada"d max="&dataa"d;
yaxis display=(noline noticks) grid;
run;

title3 "Metriche di pagina per Data - &trimestre";
title4 "Utenti coinvolti / Consumatori della pagina al giorno";
proc sgplot data=temp1 noborder;
series x=data y=utenticoinvolti / lineattrs=(color=purple thickness=2);
series x=data y=consumatori / lineattrs=(color=pink thickness=2);
xaxis display=(nolabel) grid min="&datada"d max="&dataa"d;
yaxis display=(noline noticks) grid;
run;


/************************/
/* 01 DAILY LIKE SOURCE */
/************************/

PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_like_source_01
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Like Source";
RUN;

TITLE3 "#1 Al giorno: il numero di persone che hanno messo Mi piace alla tua Pagina, suddiviso per i punti più comuni da cui si può compiere questa azione. (Utenti unici)";
RUN;

DATA TEMP;
SET facebook.daily_like_source_01;
WHERE Data not is missing;
RUN;

data total(rename=(pagelike_adder_for_reactivated_u=pagelike_adder) 
           rename=(mobile_page_suggestions_on_likin=mobile_page_sugg)
           rename=(feed_chaining_contextual_recomme=feed_chaining_con)
keep=tads 								
	tbanhammer 							
	tcomment_chaining 					
	tfeed_chaining 						
	tfeed_chaining_con 	
	tfeed_pyml 							
	tfeed_story 							
	thovercard 							
	tlaunch_point_discover_pyml 			
	tmobile 								
	tmobile_page_sugg 	
	tpage_finch_related_pages 			
	tpage_invite 						
	tpage_invite_escape_hatch 			
	tpage_profile 						
	tpage_timeline 						
	tpagelike_adder 	
	tpages_liked_feed 					
	tphoto_snowlift 						
	tprofile_edit 						
	tsearch 								
	ttimeline_like_chaining 				
	tvertex_page );
   set temp end=Lastobs;
   by data notsorted;
            tads + ads;								
	        tbanhammer + banhammer;						
			tcomment_chaining +	comment_chaining;				
			tfeed_chaining + feed_chaining;						
			tfeed_chaining_con + feed_chaining_con;
			tfeed_pyml + feed_pyml;					
			tfeed_story + feed_story;						
			thovercard + hovercard;						
			tlaunch_point_discover_pyml + launch_point_discover_pyml;	
			tmobile + mobile;							
			tmobile_page_sugg + mobile_page_sugg;
			tpage_finch_related_pages +	page_finch_related_pages;
			tpage_invite + page_invite;			
			tpage_invite_escape_hatch +	page_invite_escape_hatch;	
			tpage_profile +	page_profile;			
			tpage_timeline + page_timeline;						
			tpagelike_adder + pagelike_adder;
			tpages_liked_feed +	pages_liked_feed;	
			tphoto_snowlift + photo_snowlift;				
			tprofile_edit +	profile_edit;				
			tsearch + search;							
			ttimeline_like_chaining + timeline_like_chaining;	
			tvertex_page + vertex_page;
    if Lastobs;
run;

proc transpose data=total
               out=total_transposed;
run;

PROC TEMPLATE;
DEFINE STATGRAPH pie;
 BEGINGRAPH;
 ENTRYTITLE 'Daily Like Sources Pie Chart' ;
 LAYOUT REGION;
 PIECHART CATEGORY=COL1 /
 DATALABELLOCATION=OUTSIDE
 CATEGORYDIRECTION = CLOCKWISE
 START = 180 NAME = 'pie';
 DISCRETELEGEND 'pie' /
          TITLE = 'Daily like source';
 ENDLAYOUT;
 ENDGRAPH;
END;
RUN;
PROC SGRENDER DATA=total_transposed
 TEMPLATE=pie;
RUN; 
/*************************************************************/
/* 02 NUMERO DI PERSONE CHE LA PAGINA HA RAGGIUNTO AL GIORNO */
/*************************************************************/
TITLE3 "#2 Al giorno: il numero di persone che la tua Pagina ha raggiunto, suddiviso per il numero di volte in cui tali persone hanno visualizzato un contenuto qualsiasi relativo alla tua Pagina. (Utenti unici)"; 
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_total_freq_02
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Total frequency distri...";
RUN;

proc sgplot data=facebook.daily_total_freq_02 subpixel noborder;
series x=data y=_1 / smoothconnect lineattrs=(thickness=2);
series x=data y=_2 / smoothconnect lineattrs=(thickness=2);
series x=data y=_3 / smoothconnect lineattrs=(thickness=2);
series x=data y=_4 / smoothconnect lineattrs=(thickness=2);
series x=data y=_5 / smoothconnect lineattrs=(thickness=2);
series x=data y=_6_10 / smoothconnect lineattrs=(thickness=2);
series x=data y=_11_20 / smoothconnect lineattrs=(thickness=2);
series x=data y=_21_ / smoothconnect lineattrs=(thickness=2);
xaxis display=(nolabel) grid min="&datada"d max="&dataa"d;
yaxis label='Visite' grid;
run;

/*************************************************************/
/* 05 NUMERO DI PERSONE CHE HANNO VISTO I POST AL GIORNO     */
/*************************************************************/

TITLE3 "#5  Al giorno: il numero di persone che hanno visto i post della tua Pagina, suddiviso per il numero di volte in cui le persone hanno visto i tuoi post. (Utenti unici)";

PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_page_posts_freq_05
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Page posts frequency d...";
RUN;

proc sgplot data=facebook.daily_page_posts_freq_05 subpixel noborder;
series x=data y=_1 / smoothconnect lineattrs=(thickness=2);
series x=data y=_2 / smoothconnect lineattrs=(thickness=2);
series x=data y=_3 / smoothconnect lineattrs=(thickness=2);
series x=data y=_4 / smoothconnect lineattrs=(thickness=2);
series x=data y=_5 / smoothconnect lineattrs=(thickness=2);
series x=data y=_6_10 / smoothconnect lineattrs=(thickness=2);
series x=data y=_11_20 / smoothconnect lineattrs=(thickness=2);
series x=data y=_21_ / smoothconnect lineattrs=(thickness=2);
xaxis display=(nolabel) grid min="&datada"d max="&dataa"d;
yaxis label='Visite' grid;
run;

/********************************************************************************/
/* 08 NUMERO DI PERSONE CHE PARLANO DELLA PAGINA PER TIPO DI NOTIZIA AL GIORNO  */
/********************************************************************************/

TITLE3 "#8 Al giorno: il numero di persone che parlano della tua Pagina suddivise per tipo di notizia. (Utenti unici)";

PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_talking_about_08
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Talking About This by...";
RUN;

proc sgplot data=facebook.daily_talking_about_08 subpixel noborder;
series x=data y=checkin / smoothconnect lineattrs=(thickness=2);
series x=data y=coupon / smoothconnect lineattrs=(thickness=2);
series x=data y=event / smoothconnect lineattrs=(thickness=2);
series x=data y=fan / smoothconnect lineattrs=(thickness=2);
series x=data y=mention / smoothconnect lineattrs=(thickness=2);
series x=data y=other / smoothconnect lineattrs=(thickness=2);
series x=data y=page_post / smoothconnect lineattrs=(thickness=2);
series x=data y=question / smoothconnect lineattrs=(thickness=2);
series x=data y=user_post / smoothconnect lineattrs=(thickness=2);
xaxis display=(nolabel) grid min="&datada"d max="&dataa"d;
yaxis label='Visite' grid;
run;


/*****************************************************************************/
/* 11 NUMERO DI NOTIZIE RELATIVE PAGINA PER TIPO DI NOTIZIA AL GIORNO        */
/*****************************************************************************/
TITLE3 "#11 Al giorno: il numero di notizie relative alla tua Pagina per tipo di notizia. (Numero totale)";
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_page_stories_11
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Page Stories By Story...";
RUN;


proc sgplot data=facebook.daily_page_stories_11 subpixel noborder;
series x=data y=checkin / smoothconnect lineattrs=(thickness=2);
series x=data y=coupon / smoothconnect lineattrs=(thickness=2);
series x=data y=event / smoothconnect lineattrs=(thickness=2);
series x=data y=fan / smoothconnect lineattrs=(thickness=2);
series x=data y=mention / smoothconnect lineattrs=(thickness=2);
series x=data y=other / smoothconnect lineattrs=(thickness=2);
series x=data y=page_post / smoothconnect lineattrs=(thickness=2);
series x=data y=question / smoothconnect lineattrs=(thickness=2);
series x=data y=user_post / smoothconnect lineattrs=(thickness=2);
xaxis display=(nolabel) grid min="&datada"d max="&dataa"d;
yaxis label='Visite' grid;
run;



/*****************************************************************************/
/* 14 NUMERO DI CLIC SU UNO DEI CONTENUTI PER TIPO AL GIORNO                 */
/*****************************************************************************/
/* Non sono incluse le notizie create senza cliccare sul contenuto della Pagina (ad es. mettendo "Mi piace" a una Pagina dal diario) */
TITLE3 "#14 Numero di clic su uno dei contenuti della pagina per tipo al giorno (Numero totale)";

PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_page_consuptions_14
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Page consumptions by type";
RUN;
proc sgplot data=facebook.daily_page_consuptions_14 subpixel noborder;
series x=data y=button_clicks / smoothconnect lineattrs=(thickness=2);
series x=data y=link_clicks / smoothconnect lineattrs=(thickness=2);
series x=data y=other_clicks / smoothconnect lineattrs=(thickness=2);
series x=data y=photo_view / smoothconnect lineattrs=(thickness=2);
series x=data y=video_play / smoothconnect lineattrs=(thickness=2);
xaxis display=(nolabel) grid min="&datada"d max="&dataa"d;
yaxis label='Numero di CLIC' grid;
run;

/***************************************************************************/
/* 17 TOTALE: DATI DEMOGRAFICI AGGREGATI RELATIVI ALLE PERSONE             */
/***************************************************************************/
TITLE3 "#17 Totale: dati demografici aggregati relativi alle persone a cui piace la tua Pagina in base alle informazioni su età e genere specificate nel loro profilo. (Utenti unici)";
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.lifetime_likes_gender_17
		    DBMS=XLSX
		    REPLACE;
SHEET="Lifetime Likes by Gender and...";
RUN;

proc sgplot data=facebook.lifetime_likes_gender_17 subpixel noborder;
series x=data y=F_13_17 / smoothconnect lineattrs=(thickness=2);
series x=data y=F_18_24 / smoothconnect lineattrs=(thickness=2);
series x=data y=F_25_34 / smoothconnect lineattrs=(thickness=2);
series x=data y=F_35_44 / smoothconnect lineattrs=(thickness=2);
series x=data y=F_45_54 / smoothconnect lineattrs=(thickness=2);
series x=data y=F_55_64 / smoothconnect lineattrs=(thickness=2);
series x=data y=F_65_   / smoothconnect lineattrs=(thickness=2);
xaxis display=(nolabel) grid min="&datada"d max="&dataa"d;
yaxis label='Lifetime Likes by Gender' grid;
run;

proc sgplot data=facebook.lifetime_likes_gender_17 subpixel noborder;
series x=data y=M_13_17 / smoothconnect lineattrs=(thickness=2);
series x=data y=M_18_24 / smoothconnect lineattrs=(thickness=2);
series x=data y=M_25_34 / smoothconnect lineattrs=(thickness=2);
series x=data y=M_35_44 / smoothconnect lineattrs=(thickness=2);
series x=data y=M_45_54 / smoothconnect lineattrs=(thickness=2);
series x=data y=M_55_64 / smoothconnect lineattrs=(thickness=2);
series x=data y=M_65_   / smoothconnect lineattrs=(thickness=2);
xaxis display=(nolabel) grid min="&datada"d max="&dataa"d;
yaxis label='Lifetime Likes by Gender' grid;
run;

/*********************************************************************************/
/* 18 TOTALE: DATI AGGREGATI DI FACEBOOK SULLA POSIZIONE DELLE PERSONE PER PAESE */
/*********************************************************************************/
TITLE3 "#18 Totale: dati aggregati di Facebook sulla posizione, ordinati per Paese, sulle persone a cui piace la tua Pagina. (Utenti unici)";
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.lifetime_likes_country_18
		    DBMS=XLSX
		    REPLACE;
SHEET="Lifetime Likes By Country";
RUN;
/*
PROC MEANS DATA=facebook.lifetime_likes_country_18;
format comma10.;
var AL AR	AT	AU	BD	BE	BG	BR	CA	CH	CL	CN	CO	CZ	DE	DZ	EC	EG	ES	FR	GB	GE	GR	HU	ID	IE	IN	IQ	IT	JP	MA	MD	MK	MT	MX	NL	NO	PE	PH	PK	PL	PT	RO	RS	RU	SE	SM	TH	TN	TR	UA	US;
output out=prova;
RUN;
*/

/* Esporto i dati per il Cartogramma */
data facebook.paesi0(keep=AL AR	AT	AU	BD	BE	BG	BR	CA	CH	CL	CN	CO	CZ	DE	DZ	EC	EG	ES	FR	GB	GE	GR	HU	ID	IE	IN	IQ	IT	JP	MA	MD	MK	MT	MX	NL	NO	PE	PH	PK	PL	PT	RO	RS	RU	SE	SM	TH	TN	TR	UA	US );
   set facebook.lifetime_likes_country_18  end=Lastobs;
   by data notsorted;
    if Lastobs;
run;
proc transpose data=facebook.paesi0
               out=facebook.paesi1;
run;
proc export data=facebook.paesi1
dbms=dbf
outfile="/folders/myfolders/sasuser.v94/facebook/ne_110m_admin_0_countries/paesi1.dbf";
Run;

/* Costruisco db dati per cartogramma MONDIALE,  per aggiungere allo shapefile 
   i dati uso QGis 3.0 ed esporto un nuovo shapefile con attributi per la rappresentazione
*/

proc mapimport
    datafile='/folders/myfolders/sasuser.v94/facebook/mondo1.shp'
    out=confini create_id_;
run;
proc sort data=confini out=likes(keep=_id_ paesi1_COL) nodupkey;
    by _id_;
run;

data likes_classi(label='Classi di Like');
    set likes;
    length classe $16;
    if paesi1_COL < 20 then classe='<20 like';
    else if paesi1_COL < 50 then classe='21 - 50 like';
    else if paesi1_COL < 100 then classe='51 - 100 like';
    else if paesi1_COL < 150 then classe='101 - 150 like';
    else if paesi1_COL < 200 then classe='151 - 200 like';
    else if paesi1_COL < 250 then classe='201 - 250 like';
    else if paesi1_COL < 300 then classe='251 - 300 like';
    else if paesi1_COL < 350 then classe='301 - 350 like';
    else if paesi1_COL < 400 then classe='351 - 400 like';
    else classe='>400';
run;

title 'Comune di Rimini - Lifetime Like per Paese'; 
proc sgmap mapdata=confini maprespdata=likes_classi;
    choromap classe / mapid=_id_ id=_id_ name='Like';
    keylegend 'Like' / title='Like per Paese';
run; 
