/**************************************************************/
/** Gestisce statistiche TRIMES SU Facebook PAGE LEVEL DATA  **/
/** Author: @mauroferri Data: 8/4/2018 TAB.1-18              **/
/**************************************************************/

TITLE1 'COMUNE DI RIMINI - UFFICIO COMUNICAZIONE';

%let trimestre=Primo Trimestre 2018; /* Inserire denominazione intervallo */
%let suff=page_1TRIM2018; /* Inserire suffisso per i nomi dei file */
%let path=/folders/myfolders/sasuser.v94/facebook/;
%let eticpaesi=etichette-paesi.txt;             /* Tabelle 18 - 22 - 28 */
%let eticcitta=etichette-citta.txt;             /* Tabelle 31 */
%let varcitta=variabilicitta.txt;               /* Tabelle 31 */
%let eticdomini=etichette-domini.txt;           /* Tabelle 38 */
%let vardomini=variabilidomini.txt;
TITLE2 "Facebook Insights PAGE Level - &trimestre";
FOOTNOTE2 "Elaborazione della Redazione web &SYSDATE- Thanks to Sas University Edition 2.7 9.4 M5";
OPTIONS linesize=116 PAGESIZE=62 NONUMBER NODATE CENTER COMPRESS=yes;
LIBNAME facebook "/folders/myfolders/sasuser.v94/facebook";
%let page=/folders/myfolders/sasuser.v94/facebook/Facebook Insights Data Export - Comune di Rimini - 2018-04-04.xlsx;
filename percorso "&path";
%let datada=01JAN2018; /* Intervallo data da: configurare */
%let dataa=31MAR2018;  /* Intervallo data a: configurare */
RUN;

/******************/
/* 00 KEY METRICS */
/******************/
TITLE3 "#0 KEY METRICS";
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.key_metrics_00_&suff
		    DBMS=XLSX
		    REPLACE;
		    DATAROW=3;
SHEET="Key Metrics";
RUN;
/*
PROC MEANS N MEAN MIN MAX NMISS maxdec=0 DATA=facebook.key_metrics_page_00;
VAR _Mi_piace__in_totale Nuovi__Mi_piace__al_giorno Non_mi_piace_pi___al_giorno	
    Utenti_coinvolti_sulla_Pagina_al Copertura_totale_al_giorno Impression_totali_al_giorno 
    Visualizzazioni_della_Pagina_da Copertura_dei_post_della_Pagina Consumatori_totali_al_giorno 
    Utilizzi_della_Pagina_al_giorno Commenti_negativi_al_giorno Registrazioni_totali_al_giorno 
    Visualizzazioni_organiche_in_tot Visualizzazioni_di_30_secondi_or Visualizzazioni_totali_del_video
    Ripetizioni_del_video_al_giorno Visualizzazioni_uniche_totali_de Totale_giornaliero__numero_total
    Numero_di_clic_su_Indicazioni_st Numero_di_clic_sul_sito_Web_in_t; 
RUN;
*/

DATA TEMP(RENAME=(Nuovi__Mi_piace__al_giorno=mi_piace) rename=(Non_mi_piace_pi___al_giorno=nonmipiace) 
rename=(Utenti_coinvolti_sulla_Pagina_al=utenticoinvolti) rename=(Copertura_totale_al_giorno=copertura)
rename=(Consumatori_totali_al_giorno=consumatori) rename=(Utilizzi_della_Pagina_al_giorno=utilizzi)
rename=(Registrazioni_totali_al_giorno=registrazioni) rename=(Numero_di_clic_sul_sito_Web_in_t=clicksitoweb)
rename=(Commenti_negativi_al_giorno=commentinegativi) rename=(Impression_totali_al_giorno=impressiontot)
);
mese=month(Data);
SET facebook.key_metrics_00_&suff;
WHERE Data not is missing;
RUN;

proc sort data=TEMP out=temp1; /* Passo data per i grafici */
by mese;
where mese <> 12; /* Da correggere */
Run;

/* Statistica Trimestrale */
PROC TABULATE data=TEMP format=comma10.;
CLASS Data;
VAR mi_piace nonmipiace utenticoinvolti copertura impressiontot consumatori utilizzi commentinegativi registrazioni clicksitoweb;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
LABEL  mi_piace="Nuovi Mi Piace" nonmipiace="Non mi piace" utenticoinvolti="Utenti Coinvolti" copertura="Copertura" impressiontot="Impression" consumatori="Consumatori" utilizzi="Utilizzi" commentinegativi="Commenti negativi" registrazioni="Registrazioni" clicksitoweb="Click sul sito"; 
      TABLE Data all,mi_piace nonmipiace utenticoinvolti copertura impressiontot consumatori registrazioni utilizzi commentinegativi clicksitoweb
/ BOX="0 Key Metrics";
RUN;

/* Statistica per Mese */

PROC FORMAT;
VALUE  MESEFMT
1="Gennaio"
2="Febbraio"
3="Marzo"
4="Aprile"
5="Maggio"
6="Giugno"
7="Luglio"
8="Agosto"
9="Settembre" 
10="Ottobre"
11="Novembre"
12="Dicembre"
;
RUN;
PROC TABULATE data=TEMP1 format=comma10.;
CLASS Data;
VAR mi_piace nonmipiace utenticoinvolti copertura consumatori utilizzi registrazioni clicksitoweb;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10. mese MESEFMT.;
LABEL  mi_piace="Nuovi Mi Piace" nonmipiace="Non mi piace" utenticoinvolti="Utenti Coinvolti" copertura="Copertura" consumatori="Consumatori" utilizzi="Utilizzi" registrazioni="Registrazioni" clicksitoweb="Click sul sito"; 
      TABLE Data all,mi_piace*f=comma10. nonmipiace*f=comma10. utenticoinvolti*f=comma10. copertura*f=comma10. consumatori*f=comma10. utilizzi*f=comma10. registrazioni*f=comma10. clicksitoweb*f=comma10./ BOX="0 Key Metrics";
BY mese;
RUN;



title3 "Metriche di pagina per Data - &trimestre";
title4 "Andamento Trimestrale Mi piace";
proc sgplot data=temp1 noborder;
series x=data y=_Mi_piace__in_totale  / smoothconnect lineattrs=(color=green thickness=2);
xaxis display=(nolabel) grid min="&datada"d max="&dataa"d;
yaxis display=(noline noticks) grid;
run;

title3 "Metriche di pagina per Data - &trimestre";
title4 "Mi piace e Non mi piace al giorno";
proc sgplot data=temp1 noborder;
series x=data y=mi_piace / lineattrs=(color=green thickness=2);
series x=data y=nonmipiace / lineattrs=(color=red thickness=1)  ;
xaxis display=(nolabel) grid min="&datada"d max="&dataa"d;
yaxis display=(noline noticks) grid;
run;

title3 "Metriche di pagina per Data - &trimestre";
title4 "Copertura totale e utilizzi della pagina al giorno";
proc sgplot data=temp1 noborder;
series x=data y=copertura / lineattrs=(color=blue thickness=2);
series x=data y=Utilizzi / lineattrs=(color=cyan thickness=2);
xaxis display=(nolabel) grid min="&datada"d max="&dataa"d;
yaxis display=(noline noticks) grid;
run;

title3 "Metriche di pagina per Data - &trimestre";
title4 "Utenti coinvolti / Consumatori della pagina al giorno";
proc sgplot data=temp1 noborder;
series x=data y=utenticoinvolti / lineattrs=(color=purple thickness=2);
series x=data y=consumatori / lineattrs=(color=pink thickness=2);
xaxis display=(nolabel) grid min="&datada"d max="&dataa"d;
yaxis display=(noline noticks) grid;
run;


/************************/
/* 01 DAILY LIKE SOURCE */
/************************/

PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_like_01_&suff
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Like Source";
RUN;

TITLE3 "#1 Al giorno: il numero di persone che hanno messo Mi piace alla tua Pagina, suddiviso per i punti più comuni da cui si può compiere questa azione. (Utenti unici)";
RUN;
/* PROC MEANS N MEAN MIN MAX NMISS maxdec=0 DATA=facebook.daily_like_source_01; RUN;;
VAR ads banhammer comment_chaining feed_chaining feed_chaining_contextual_recomme feed_pyml feed_story 							
	hovercard launch_point_discover_pyml mobile mobile_page_suggestions_on_likin
	page_finch_related_pages page_invite page_invite_escape_hatch page_profile page_timeline 						
	pagelike_adder_for_reactivated_u pages_liked_feed photo_snowlift profile_edit search timeline_like_chaining 				
	vertex_page; 
RUN; */

proc TABULATE data=facebook.daily_like_01_&suff;
CLASS Data;
VAR page_profile feed_story search hovercard mobile ads banhammer feed_chaining feed_story page_invite page_invite_escape_hatch 
    page_timeline pages_liked_feed photo_snowlift;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
LABEL page_profile="PageProfile" feed_story="FeedStory" search="Search" hovercard="Hovercard" mobile="Mobile" ads="Ads"
      banhammer="BanHammer" feed_chaining="FeedChaining" page_invite="PageInvite" page_invite_escape_hatch="PageInviteEsc" 
      page_timeline="PageTimeline" pages_liked_feed="PageLikedFeed" photo_snowlift="PhotoSnowlift"; 
      TABLE
      Data ALL, page_profile*f=comma10.  feed_story*f=comma10. search*f=comma10. hovercard*f=comma10. mobile*f=comma10.
                ads*f=comma10. banhammer*f=comma10. feed_chaining*f=comma10. page_invite*f=comma10. page_invite_escape_hatch*f=comma10.
                page_timeline*f=comma10. pages_liked_feed*f=comma10. photo_snowlift*f=comma10. 
       / BOX="1 Daily Like Sources";
RUN;

DATA TEMP;
SET facebook.daily_like_01_&suff;
WHERE Data not is missing;
RUN;

data total(rename=(pagelike_adder_for_reactivated_u=pagelike_adder) 
           rename=(mobile_page_suggestions_on_likin=mobile_page_sugg)
           rename=(feed_chaining_contextual_recomme=feed_chaining_con)
	keep=tads tbanhammer tcomment_chaining tfeed_chaining tfeed_chaining_con tfeed_pyml tfeed_story 							
	thovercard 	tlaunch_point_discover_pyml tmobile tmobile_page_sugg tpage_finch_related_pages tpage_invite 						
	tpage_invite_escape_hatch tpage_profile tpage_timeline tpagelike_adder tpages_liked_feed tphoto_snowlift 						
	tprofile_edit tsearch ttimeline_like_chaining tvertex_page );
   set temp end=Lastobs;
   by data notsorted;
            tads + ads;								
	        tbanhammer + banhammer;						
			tcomment_chaining +	comment_chaining;				
			tfeed_chaining + feed_chaining;						
			tfeed_chaining_con + feed_chaining_con;
			tfeed_pyml + feed_pyml;					
			tfeed_story + feed_story;						
			thovercard + hovercard;						
			tlaunch_point_discover_pyml + launch_point_discover_pyml;	
			tmobile + mobile;							
			tmobile_page_sugg + mobile_page_sugg;
			tpage_finch_related_pages +	page_finch_related_pages;
			tpage_invite + page_invite;			
			tpage_invite_escape_hatch +	page_invite_escape_hatch;	
			tpage_profile +	page_profile;			
			tpage_timeline + page_timeline;						
			tpagelike_adder + pagelike_adder;
			tpages_liked_feed +	pages_liked_feed;	
			tphoto_snowlift + photo_snowlift;				
			tprofile_edit +	profile_edit;				
			tsearch + search;							
			ttimeline_like_chaining + timeline_like_chaining;	
			tvertex_page + vertex_page;
    if Lastobs;
run;

proc transpose data=total
               out=total_transposed;
run;

proc format;
     value $likesources
     'tads'= 'People who clicked Like in an Ad or Sponsored Story pointing to your Page'								
	 'tbanhammer'= 'People who like your page banhammer'						
	 'tcomment_chaining'= 'Comment Chaining'					
	 'tfeed_chaining'= 'People who liked your Page after Facebook automatically suggested a story about a friend liking your page.'						
	 'tfeed_chaining_con'= 'Feed Chining Connected'	
	 'tfeed_pyml'='Mi Piace provenienti dal modulo Pages You May Like che appare nella navigazione del News Feed.'							
	 'tfeed_story'= 'Feed Story'							
	 'thovercard'='People who liked your Page from the popup window they get when they hover over a link that leads to your Page'							
	 'tlaunch_point_discover_pyml'='Like provenienti dal box Pages You May Like (pyml) che mostra Pagine simili a quella su cui un utente ha appena selezionato Mi Piace' 			
	 'tmobile'='People who liked your Page from a mobile device' 								
	 'tmobile_page_sugg'='Mi Piace provenienti dalle Pagine suggerite all utente in seguito alla selezione di un Mi Piace da dispositivo mobile' 	
	 'tpage_finch_related_pages'='Finch related pages' 			
	 'tpage_invite'= 'People who liked your Page after being invited'						
	 'tpage_invite_escape_hatch'= 'People who invite escape access'			
	 'tpage_profile'= 'People who liked your Page on the Page itself or in a News Feed or ticker story'						
	 'tpage_timeline'= 'Pagina timeline'						
	 'tpagelike_adder'= 	'Aggiunta pagine'
	 'tpages_liked_feed'= 'Like Feed'					
	 'tphoto_snowlift'= 'Like provenienti dalla visualizzazione di foto pubblicate dalla Pagina'						
	 'tprofile_edit'= 'Profile edit'						
	 'tsearch'='People who liked your Page from their search results'								
	 'ttimeline_like_chaining'='People who liked your Page from the Likes section of their own Timeline or someone else'
	 'tvertex_page'='Nertex';
run;

proc print data=total_transposed ;
format _NAME_ $likesources.;
Run;
proc report data=total_transposed ;
define col1 / 'Totale';
format _NAME_ $likesources.;
Run;
PROC TEMPLATE ;
DEFINE STATGRAPH pie;
 BEGINGRAPH;
 ENTRYTITLE 'Daily Like Sources Pie Chart' ;
 LAYOUT REGION;
  PIECHART CATEGORY=COL1 /
 DATALABELLOCATION=OUTSIDE
 CATEGORYDIRECTION = CLOCKWISE
 START = 180 NAME = 'pie';
 DISCRETELEGEND 'pie' /
 TITLE = 'Daily like source';
  ENDLAYOUT;
 ENDGRAPH;
END;
RUN;
PROC SGRENDER DATA=total_transposed
 TEMPLATE=pie;
RUN; 


/*************************************************************/
/* 02 NUMERO DI PERSONE CHE LA PAGINA HA RAGGIUNTO AL GIORNO */
/*************************************************************/
TITLE3 "#2 Al giorno: il numero di persone che la tua Pagina ha raggiunto, suddiviso per il numero di volte in cui tali persone hanno visualizzato un contenuto qualsiasi relativo alla tua Pagina. (Utenti unici)"; 
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_tfreq_02_&suff
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Total frequency distri...";
RUN;
/*
PROC MEANS DATA=facebook.daily_total_freq_02 maxdec=2;
Format _1 comma10. _2 comma10. _3 comma10. _4 comma10. _5 comma10. _6 comma10. _11_20 comma10. _21_ comma10.;
VAR _1
	_2
	_3
	_4
	_5
	_6_10
	_11_20
	_21_;
RUN;
PROC CONTENTS VARNUM DATA=facebook.daily_total_freq_02;
RUN;
*/
proc TABULATE data=facebook.daily_tfreq_02_&suff ;
CLASS Data;
VAR _1 _2 _3 _4 _5 _6_10 _11_20 _21_;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
LABEL _1="1 vis." _2="2 vis." _3="3 vis." _4="4 vis." _5="5 vis." _6_10="da 6 a 10 vis." _11_20="da 11 a 20 vis." _21_="oltre 21"; 
      TABLE
      Data all, _1*f=comma10. _2*f=comma10. _3*f=comma10. _4*f=comma10. _5*f=comma10. _6_10*f=comma10. _11_20*f=comma10. _21_*f=comma10. / BOX="2 Daily Total Frequency";
RUN;


/*************************************************************/
/* 03 NUMERO DI PERSONE CHE LA PAGINA HA RAGGIUNTO ALLA SETT */
/*************************************************************/

TITLE3 "#3 Settimanale: il numero di persone che la tua Pagina ha raggiunto, suddiviso per il numero di volte in cui tali persone hanno visualizzato un contenuto qualsiasi relativo alla tua Pagina. (Utenti unici)";

PROC IMPORT DATAFILE="&page"
		    OUT=facebook.weekly_tfreq_03_&suff
		    DBMS=XLSX
		    REPLACE;
SHEET="Weekly Total frequency distr...";
RUN;

/*
PROC MEANS DATA=facebook.weekly_total_freq_03 maxdec=2;
Format _1 comma10. _2 comma10. _3 comma10. _4 comma10. _5 comma10. _6 comma10. _11_20 comma10. _21_ comma10.;
VAR _1
	_2
	_3
	_4
	_5
	_6_10
	_11_20
	_21_;
RUN;
*/


proc TABULATE data=facebook.weekly_tfreq_03_&suff ;
CLASS Data;
VAR _1 _2 _3 _4 _5 _6_10 _11_20 _21_;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
LABEL _1="1 vis." _2="2 vis." _3="3 vis." _4="4 vis." _5="5 vis." _6_10="da 6 a 10 vis." _11_20="da 11 a 20 vis." _21_="oltre 21"; 
      TABLE
      Data all, _1*f=comma10. _2*f=comma10. _3*f=comma10. _4*f=comma10. _5*f=comma10. _6_10*f=comma10. _11_20*f=comma10. _21_*f=comma10. / BOX="3 Daily Total Frequency";
RUN;
*/

/*************************************************************/
/* 04 NUMERO DI PERSONE CHE LA PAGINA HA RAGGIUNTO AL MESE   */
/*************************************************************/

TITLE3 "#4 28 giorni: il numero di persone che la tua Pagina ha raggiunto, suddivisi in base a quante volte le persone hanno visto uno dei contenuti relativi alla tua Pagina. (Utenti unici)";

PROC IMPORT DATAFILE="&page"
		    OUT=facebook.days28_tfreq_04_&suff
		    DBMS=XLSX
		    REPLACE;
SHEET="28 Days Total frequency dist...";
RUN;

/*
PROC MEANS DATA=facebook.days28_total_freq_04 maxdec=2;
Format _1 comma10. _2 comma10. _3 comma10. _4 comma10. _5 comma10. _6 comma10. _11_20 comma10. _21_ comma10.;
VAR _1
	_2
	_3
	_4
	_5
	_6_10
	_11_20
	_21_;
RUN;
*/


proc TABULATE data=facebook.days28_tfreq_04_&suff ;
CLASS Data;
VAR _1 _2 _3 _4 _5 _6_10 _11_20 _21_;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
LABEL _1="1 vis." _2="2 vis." _3="3 vis." _4="4 vis." _5="5 vis." _6_10="da 6 a 10 vis." _11_20="da 11 a 20 vis." _21_="oltre 21"; 
      TABLE
      Data all, _1*f=comma10. _2*f=comma10. _3*f=comma10. _4*f=comma10. _5*f=comma10. _6_10*f=comma10. _11_20*f=comma10. _21_*f=comma10. / BOX="4 Daily Total Frequency";
RUN;


/*************************************************************/
/* 05 NUMERO DI PERSONE CHE HANNO VISTO I POST AL GIORNO     */
/*************************************************************/

TITLE3 "#5  Al giorno: il numero di persone che hanno visto i post della tua Pagina, suddiviso per il numero di volte in cui le persone hanno visto i tuoi post. (Utenti unici)";

PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_pfreq_05_&suff
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Page posts frequency d...";
RUN;

/*
PROC MEANS DATA=facebook.daily_pfreq_05_&suff maxdec=2;
Format _1 comma10. _2 comma10. _3 comma10. _4 comma10. _5 comma10. _6 comma10. _11_20 comma10. _21_ comma10.;
VAR _1
	_2
	_3
	_4
	_5
	_6_10
	_11_20
	_21_;
RUN;
*/

proc TABULATE data=facebook.daily_pfreq_05_&suff;
CLASS Data;
VAR _1 _2 _3 _4 _5 _6_10 _11_20 _21_;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
LABEL _1="1 vis." _2="2 vis." _3="3 vis." _4="4 vis." _5="5 vis." _6_10="da 6 a 10 vis." _11_20="da 11 a 20 vis." _21_="oltre 21"; 
      TABLE
      Data all, _1*f=comma10. _2*f=comma10. _3*f=comma10. _4*f=comma10. _5*f=comma10. _6_10*f=comma10. _11_20*f=comma10. _21_*f=comma10. / BOX="5 Daily Page posts frequency";
RUN;


/*************************************************************/
/* 06 NUMERO DI PERSONE CHE HANNO VISTO I POST ALLA SETTIMANA*/
/*************************************************************/

TITLE3 "#6 Settimanale: il numero di persone che hanno visto i post della tua Pagina, suddiviso per il numero di volte in cui le persone hanno visto i tuoi post. (Utenti unici)";

PROC IMPORT DATAFILE="&page"
		    OUT=facebook.weekly_pposts_06_&suff
		    DBMS=XLSX
		    REPLACE;
SHEET="Weekly Page posts frequency...";
RUN;


/*
PROC MEANS DATA=facebook.weekly_page_posts_06 maxdec=2;
Format _1 comma10. _2 comma10. _3 comma10. _4 comma10. _5 comma10. _6 comma10. _11_20 comma10. _21_ comma10.;
VAR _1
	_2
	_3
	_4
	_5
	_6_10
	_11_20
	_21_;
RUN;
*/


proc TABULATE data=facebook.weekly_pposts_06_&suff ;
CLASS Data;
VAR _1 _2 _3 _4 _5 _6_10 _11_20 _21_;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
LABEL _1="1 vis." _2="2 vis." _3="3 vis." _4="4 vis." _5="5 vis." _6_10="da 6 a 10 vis." _11_20="da 11 a 20 vis." _21_="oltre 21"; 
      TABLE
      Data all, _1*f=comma10. _2*f=comma10. _3*f=comma10. _4*f=comma10. _5*f=comma10. _6_10*f=comma10. _11_20*f=comma10. _21_*f=comma10. / BOX="6 Daily Page posts frequency";
RUN;
*/

/*************************************************************/
/* 07 NUMERO DI PERSONE CHE HANNO VISTO I POST AL MESE       */
/*************************************************************/

TITLE3 "#7 28 giorni:  il numero di persone che hanno visto i post della tua Pagina, suddiviso per il numero di volte in cui le persone hanno visto i tuoi post. (Utenti unici)";

PROC IMPORT DATAFILE="&page"
		    OUT=facebook.days28_pp_freq_07_&suff
		    DBMS=XLSX
		    REPLACE;
SHEET="28 Days Page posts frequency...";
RUN;


/*
PROC MEANS DATA=facebook.days28_page_posts_freq_07;
Format _1 comma10. _2 comma10. _3 comma10. _4 comma10. _5 comma10. _6 comma10. _11_20 comma10. _21_ comma10.;
VAR _1
	_2
	_3
	_4
	_5
	_6_10
	_11_20
	_21_;
RUN;
*/

proc TABULATE data=facebook.days28_pp_freq_07_&suff;
CLASS Data;
VAR _1 _2 _3 _4 _5 _6_10 _11_20 _21_;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
LABEL _1="1 vis." _2="2 vis." _3="3 vis." _4="4 vis." _5="5 vis." _6_10="da 6 a 10 vis." _11_20="da 11 a 20 vis." _21_="oltre 21"; 
      TABLE
      Data all, _1*f=comma10. _2*f=comma10. _3*f=comma10. _4*f=comma10. _5*f=comma10. _6_10*f=comma10. _11_20*f=comma10. _21_*f=comma10. / BOX="7 Daily Page posts frequency";
RUN;


/********************************************************************************/
/* 08 NUMERO DI PERSONE CHE PARLANO DELLA PAGINA PER TIPO DI NOTIZIA AL GIORNO  */
/********************************************************************************/

TITLE3 "#8 Al giorno: il numero di persone che parlano della tua Pagina suddivise per tipo di notizia. (Utenti unici)";

PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_talking_08_&suff
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Talking About This by...";
RUN;

/*
PROC MEANS DATA=facebook.daily_talking_about_08 MAXDEC=0;
var checkin
	coupon
	event
	fan
	mention
	other
	page_post
	question
	user_post;
RUN;
*/

proc TABULATE data=facebook.daily_talking_08_&suff ;
CLASS Data;
VAR checkin
	coupon
	event
	fan
	mention
	other
	page_post
	question
	user_post;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
LABEL checkin="Check in" coupon="Coupon" event="Evento" fan="Fan" mention="Mention o Tag" other="Altro" page_post="Page Post" question="Domanda" user_post="Post utente"; 
      TABLE
      Data all, checkin*f=comma10. coupon*f=comma10. event*f=comma10. fan*f=comma10. mention*f=comma10. other*f=comma10. page_post*f=comma10. question*f=comma10. user_post*f=comma10./ BOX="8 Daily Talking About - al giorno";
RUN;

/*
DATA TEMP;
mese=month(Data);
SET facebook.daily_talking_08_&suff;
RUN;
proc sort data=TEMP;
by mese;
Run;

PROC FORMAT;
VALUE  MESEFMT
1="Gennaio"
2="Febbraio"
3="Marzo"
4="Aprile"
5="Maggio"
6="Giugno"
7="Luglio"
8="Agosto"
9="Settembre" 
10="Ottobre"
11="Novembre"
12="Dicembre"
;
RUN;

proc TABULATE data=TEMP ;
CLASS Data;
VAR checkin
	coupon
	event
	fan
	mention
	other
	page_post
	question
	user_post;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10. mese MESEFMT.;
LABEL checkin="Check in" coupon="Coupon" event="Evento" fan="Fan" mention="Mention o Tag" other="Altro" page_post="Page Post" question="Domanda" user_post="Post utente"; 
      TABLE
      Data all, checkin*f=comma10. coupon*f=comma10. event*f=comma10. fan*f=comma10. mention*f=comma10. other*f=comma10. page_post*f=comma10. question*f=comma10. user_post*f=comma10./ BOX="8 Daily Talking About - al giorno";
by mese;
RUN;
*/

/************************************************************************************/
/* 09 NUMERO DI PERSONE CHE PARLANO DELLA PAGINA PER TIPO DI NOTIZIA ALLA SETTIMANA */
/************************************************************************************/

TITLE3 "#9 Settimanale: il numero di persone che parlano della tua Pagina suddivise per tipo di notizia. (Utenti unici)";

PROC IMPORT DATAFILE="&page"
		    OUT=facebook.weekly_talking_09_&suff
		    DBMS=XLSX
		    REPLACE;
SHEET="Weekly Talking About This by...";
RUN;

proc TABULATE data=facebook.weekly_talking_09_&suff ;
CLASS Data;
VAR checkin
	coupon
	event
	fan
	mention
	other
	page_post
	question
	user_post;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
LABEL checkin="Check in" coupon="Coupon" event="Evento" fan="Fan" mention="Mention o Tag" other="Altro" page_post="Page Post" question="Domanda" user_post="Post utente"; 
      TABLE
      Data all, checkin*f=comma10. coupon*f=comma10. event*f=comma10. fan*f=comma10. mention*f=comma10. other*f=comma10. page_post*f=comma10. question*f=comma10. user_post*f=comma10./ BOX="9 Daily Talking About - alla settimana";
RUN;
*/

/*****************************************************************************/
/* 10 NUMERO DI PERSONE CHE PARLANO DELLA PAGINA PER TIPO DI NOTIZIA AL MESE */
/*****************************************************************************/

TITLE3 "#10 28 giorni: il numero di persone che parlano della tua Pagina suddivise per tipo di notizia. (Utenti unici)";
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.days28_talking_10_&suff
		    DBMS=XLSX
		    REPLACE;
SHEET="28 Days Talking About This b...";
RUN;

proc TABULATE data=facebook.days28_talking_10_&suff ;
CLASS Data;
VAR checkin
	coupon
	event
	fan
	mention
	other
	page_post
	question
	user_post;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
LABEL checkin="Check in" coupon="Coupon" event="Evento" fan="Fan" mention="Mention o Tag" other="Altro" page_post="Page Post" question="Domanda" user_post="Post utente"; 
      TABLE
      Data all, checkin*f=comma10. coupon*f=comma10. event*f=comma10. fan*f=comma10. mention*f=comma10. other*f=comma10. page_post*f=comma10. question*f=comma10. user_post*f=comma10./ BOX="10 Daily Talking About - 28 giorni";
RUN;


/*****************************************************************************/
/* 11 NUMERO DI NOTIZIE RELATIVE PAGINA PER TIPO DI NOTIZIA AL GIORNO        */
/*****************************************************************************/
TITLE3 "#11 Al giorno: il numero di notizie relative alla tua Pagina per tipo di notizia. (Numero totale)";
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_stories_11_&suff
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Page Stories By Story...";
RUN;

proc TABULATE data=facebook.daily_stories_11_&suff ;
CLASS Data;
VAR checkin
	coupon
	event
	fan
	mention
	other
	page_post
	question
	user_post;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
LABEL checkin="Check in" coupon="Coupon" event="Evento" fan="Fan" mention="Mention o Tag" other="Altro" page_post="Page Post" question="Domanda" user_post="Post utente"; 
      TABLE
      Data all, checkin*f=comma10. coupon*f=comma10. event*f=comma10. fan*f=comma10. mention*f=comma10. 
      other*f=comma10. page_post*f=comma10. question*f=comma10. user_post*f=comma10.
      / BOX="11 Daily Page Stories By Story";
RUN;


/*****************************************************************************/
/* 12 NUMERO DI NOTIZIE RELATIVE PAGINA PER TIPO DI NOTIZIA AL SETTIMANALE   */
/*****************************************************************************/

TITLE3 "#12 Settimanale: il numero di notizie relative alla tua Pagina per tipo di notizia (Numero totale)";

PROC IMPORT DATAFILE="&page"
		    OUT=facebook.weekly_stories_12_&suff
		    DBMS=XLSX
		    REPLACE;
SHEET="Weekly Page Stories by story...";
RUN;

proc TABULATE data=facebook.weekly_stories_12_&suff ;
CLASS Data;
VAR checkin
	coupon
	event
	fan
	mention
	other
	page_post
	question
	user_post;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
LABEL checkin="Check in" coupon="Coupon" event="Evento" fan="Fan" mention="Mention o Tag" other="Altro" page_post="Page Post" question="Domanda" user_post="Post utente"; 
      TABLE
      Data all, checkin*f=comma10. coupon*f=comma10. event*f=comma10. fan*f=comma10. mention*f=comma10. 
      other*f=comma10. page_post*f=comma10. question*f=comma10. user_post*f=comma10.
      / BOX="12 Daily Page Stories By Story";
RUN;


/*****************************************************************************/
/* 13 NUMERO DI NOTIZIE RELATIVE PAGINA PER TIPO DI NOTIZIA AL MESE          */
/*****************************************************************************/

TITLE3 "#13 28 giorni: il numero di notizie relative alla tua Pagina per tipo di notizia (Numero totale)";

PROC IMPORT DATAFILE="&page"
		    OUT=facebook.days28_stories_13_&suff
		    DBMS=XLSX
		    REPLACE;
SHEET="28 Days Page Stories By Stor...";
RUN;

proc TABULATE data=facebook.days28_stories_13_&suff ;
CLASS Data;
VAR checkin
	coupon
	event
	fan
	mention
	other
	page_post
	question
	user_post;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
LABEL checkin="Check in" coupon="Coupon" event="Evento" fan="Fan" mention="Mention o Tag" other="Altro" page_post="Page Post" question="Domanda" user_post="Post utente"; 
      TABLE
      Data all, checkin*f=comma10. coupon*f=comma10. event*f=comma10. fan*f=comma10. mention*f=comma10. 
      other*f=comma10. page_post*f=comma10. question*f=comma10. user_post*f=comma10.
      / BOX="13 Daily Page Stories By Story";
RUN;


/*****************************************************************************/
/* 14 NUMERO DI CLIC SU UNO DEI CONTENUTI PER TIPO AL GIORNO                 */
/*****************************************************************************/
/* Non sono incluse le notizie create senza cliccare sul contenuto della Pagina (ad es. mettendo "Mi piace" a una Pagina dal diario) */
TITLE3 "#14 Numero di clic su uno dei contenuti della pagina per tipo al giorno (Numero totale)";

PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_consupt_14_&suff
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Page consumptions by type";
RUN;


proc TABULATE data=facebook.daily_consupt_14_&suff ;
CLASS Data;
VAR button_clicks
	link_clicks
	other_clicks
	photo_view
	video_play
;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
      TABLE
      Data all, button_clicks*f=comma10. link_clicks*f=comma10. other_clicks*f=comma10. photo_view*f=comma10. video_play*f=comma10. 
      / BOX="14 Daily Page consumptions by type";
RUN;



/*****************************************************************************/
/* 15 NUMERO DI CLIC SU UNO DEI CONTENUTI PER TIPO ALLA SETTIMANA            */
/*****************************************************************************/
/* Non sono incluse le notizie create senza cliccare sul contenuto della Pagina (ad es. mettendo "Mi piace" a una Pagina dal diario) */

TITLE3 "#15 Numero di clic su uno dei contenuti della pagina per tipo alla settimana (Numero totale)";


PROC IMPORT DATAFILE="&page"
		    OUT=facebook.weekly_consupt_15_&suff
		    DBMS=XLSX
		    REPLACE;
SHEET="Weekly Page consumptions by...";
RUN;

proc TABULATE data=facebook.weekly_consupt_15_&suff ;
CLASS Data;
VAR button_clicks
	link_clicks
	other_clicks
	photo_view
	video_play
;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
      TABLE
      Data all, button_clicks*f=comma10. link_clicks*f=comma10. other_clicks*f=comma10. photo_view*f=comma10. video_play*f=comma10. 
      / BOX="15 Daily Page consumptions by type";
RUN;


/*****************************************************************************/
/* 16 NUMERO DI CLIC SU UNO DEI CONTENUTI PER TIPO Al mese .                 */
/*****************************************************************************/
/* Non sono incluse le notizie create senza cliccare sul contenuto della Pagina (ad es. mettendo "Mi piace" a una Pagina dal diario) */


TITLE3 "#16 Numero di clic su uno dei contenuti della pagina per tipo al mese (Numero totale)";

PROC IMPORT DATAFILE="&page"
		    OUT=facebook.days28_consupt_16_&suff
		    DBMS=XLSX
		    REPLACE;
SHEET="28 Days Page consumptions by...";
RUN;

proc TABULATE data=facebook.days28_consupt_16_&suff ;
CLASS Data;
VAR button_clicks
	link_clicks
	other_clicks
	photo_view
	video_play
;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
      TABLE
      Data all, button_clicks*f=comma10. link_clicks*f=comma10. other_clicks*f=comma10. photo_view*f=comma10. video_play*f=comma10. 
      / BOX="16 Daily Page consumptions by type";
RUN;


/***************************************************************************/
/* 17 TOTALE: DATI DEMOGRAFICI AGGREGATI RELATIVI ALLE PERSONE             */
/***************************************************************************/
TITLE3 "#17 Totale: dati demografici aggregati relativi alle persone a cui piace la tua Pagina in base alle informazioni su età e genere specificate nel loro profilo. (Utenti unici)";
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.lt_like_gend_17_&suff
		    DBMS=XLSX
		    REPLACE;
SHEET="Lifetime Likes by Gender and...";
RUN;
/*
PROC MEANS data=facebook.lifetime_likes_gender_17;
VAR F_13_17
	F_18_24
	F_25_34
	F_35_44
	F_45_54
	F_55_64
	F_65_
	M_13_17
	M_18_24
	M_25_34
	M_35_44
	M_45_54
	M_55_64
	M_65_
	U_13_17
	U_18_24
	U_25_34
	U_35_44
	U_45_54
	U_55_64
	U_65_;
RUN;
*/
proc TABULATE data=facebook.lt_like_gend_17_&suff ;
CLASS Data;
VAR F_13_17 F_18_24 F_25_34 F_35_44 F_45_54 F_55_64 F_65_ M_13_17 M_18_24 M_25_34 M_35_44 M_45_54 M_55_64 M_65_
	U_13_17 U_18_24 U_25_34 U_35_44 U_45_54 U_55_64 U_65_;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
LABEL F_13_17="F 13-17" F_18_24="F 18-24" F_25_34="F 25-34" F_35_44="F 35-44" F_45_54="F 45-54" F_55_64="F 55-64" F_65_="F 65+"
      M_13_17="M 13-17" M_18_24="M 18-24" M_25_34="M 25-34" M_35_44="M 35-44" M_45_54="M 45-54" M_55_64="M 55-64" M_65_="M 65+"
      U_13_17="U 13-17" U_18_24="U 18-24" U_25_34="U 25-34" U_35_44="U 35-44" U_45_54="U 45-54" U_55_64="U 55-64" U_65_="U 65+"; 
      TABLE
      Data all, F_13_17*f=comma10. F_18_24*f=comma10. F_25_34*f=comma10. F_35_44*f=comma10. F_45_54*f=comma10. F_55_64*f=comma10. F_65_*f=comma10. 
      			M_13_17*f=comma10. M_18_24*f=comma10. M_25_34*f=comma10. M_35_44*f=comma10. M_45_54*f=comma10. M_55_64*f=comma10. M_65_*f=comma10.
				U_13_17*f=comma10. U_18_24*f=comma10. U_25_34*f=comma10. U_35_44*f=comma10. U_45_54*f=comma10. U_55_64*f=comma10. U_65_*f=comma10.
      / BOX="17 Lifetime Likes by Gender and Age";
RUN;



/*********************************************************************************/
/* 18 TOTALE: DATI AGGREGATI DI FACEBOOK SULLA POSIZIONE DELLE PERSONE PER PAESE */
/*********************************************************************************/
TITLE3 "#18 Totale: dati aggregati di Facebook sulla posizione, ordinati per Paese, sulle persone a cui piace la tua Pagina. (Utenti unici)";
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.lt_like_count_18_&suff
		    DBMS=XLSX
		    REPLACE;
SHEET="Lifetime Likes By Country";
RUN;

/*
PROC MEANS DATA=facebook.lifetime_likes_country_18 ;
RUN;
PROC PRINT DATA=facebook.lifetime_likes_country_18 ;
RUN;
*/

proc TABULATE data=facebook.lt_like_count_18_&suff format=comma10.;
  CLASS Data;
  VAR AL
AR
AT
AU
BD
BE
BG
BR
CA
CH
CL
CN
CO
CZ
DE
DZ
EC
EG
ES
FR
GB
GE
GR
HU
ID
IE
IN
IQ
IT
JP
MA
MD
MK
MT
MX
NL
NO
PE
PH
PK
PL
PT
RO
RS
RU
SE
SM
TH
TN
TR
UA
US;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
LABEL  
%inc percorso(etichette-paesi.txt);
 ;
FORMAT Data DDMMYY10.;
      TABLE
      Data all, AL
AR
AT
AU
BD
BE
BG
BR
CA
CH
CL
CN
CO
CZ
DE
DZ
EC
EG
ES
FR
GB
GE
GR
HU
ID
IE
IN
IQ
IT
JP
MA
MD
MK
MT
MX
NL
NO
PE
PH
PK
PL
PT
RO
RS
RU
SE
SM
TH
TN
TR
UA
US  
      / BOX="18 Lifetime Likes By Country";
RUN;
